=====
Usage
=====

To use `send_words` to send words list in a project::

    >>> from send_words.send_words import sendingWords
    >>> sendingWords('send_words/Diccionario.txt')

And will open a browser with Silabeador page receiving the words sent from package
   

To use `send_words` to generate random quotes in a project::

    >>> from send_words.send_words import quotes
    >>> quotes()